Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(288)

Unified Diff: webkit/glue/weburlrequest.h

Issue 115717: Roll webkit DEPS and fix compile errors. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/glue/webframeloaderclient_impl.cc ('k') | webkit/glue/weburlrequest_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/weburlrequest.h
===================================================================
--- webkit/glue/weburlrequest.h (revision 16750)
+++ webkit/glue/weburlrequest.h (working copy)
@@ -37,10 +37,10 @@
virtual GURL GetURL() const = 0;
virtual void SetURL(const GURL& url) = 0;
- // Get/set the main document URL, which may be different from the URL for a
- // subframe load.
- virtual GURL GetMainDocumentURL() const = 0;
- virtual void SetMainDocumentURL(const GURL& url) = 0;
+ // Get/set the URL of the first party for cookies, which may be different
wtc 2009/05/22 20:46:03 What does the first party for cookies mean?
+ // from the URL for a subframe load.
+ virtual GURL GetFirstPartyForCookies() const = 0;
+ virtual void SetFirstPartyForCookies(const GURL& url) = 0;
// Get/set the cache policy.
virtual WebRequestCachePolicy GetCachePolicy() const = 0;
« no previous file with comments | « webkit/glue/webframeloaderclient_impl.cc ('k') | webkit/glue/weburlrequest_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698